aboutsummaryrefslogtreecommitdiffstats
path: root/src/atimer.c
diff options
context:
space:
mode:
authorPaul Eggert <[email protected]>2011-03-17 23:48:05 -0700
committerPaul Eggert <[email protected]>2011-03-17 23:48:05 -0700
commit3e7d65943519072e22cb3bcff3897805f5bae7a8 (patch)
tree8c63d5ea2e1730781b30d74aa38d0a838a3b1b2c /src/atimer.c
parent8176119bc432d0ddb6187a4a84c81a7d9489153a (diff)
* atimer.c (start_atimer, append_atimer_lists, set_alarm): Rename
locals to avoid shadowing.
Diffstat (limited to 'src/atimer.c')
-rw-r--r--src/atimer.c47
1 files changed, 23 insertions, 24 deletions
diff --git a/src/atimer.c b/src/atimer.c
index 309a4eaee4..e10add961e 100644
--- a/src/atimer.c
+++ b/src/atimer.c
@@ -86,7 +86,7 @@ SIGTYPE alarm_signal_handler (int signo);
to cancel_atimer; don't free it yourself. */
struct atimer *
-start_atimer (enum atimer_type type, EMACS_TIME time, atimer_callback fn,
+start_atimer (enum atimer_type type, EMACS_TIME timestamp, atimer_callback fn,
void *client_data)
{
struct atimer *t;
@@ -94,10 +94,10 @@ start_atimer (enum atimer_type type, EMACS_TIME time, atimer_callback fn,
/* Round TIME up to the next full second if we don't have
itimers. */
#ifndef HAVE_SETITIMER
- if (EMACS_USECS (time) != 0)
+ if (EMACS_USECS (timestamp) != 0)
{
- EMACS_SET_USECS (time, 0);
- EMACS_SET_SECS (time, EMACS_SECS (time) + 1);
+ EMACS_SET_USECS (timestamp, 0);
+ EMACS_SET_SECS (timestamp, EMACS_SECS (timestamp) + 1);
}
#endif /* not HAVE_SETITIMER */
@@ -123,18 +123,18 @@ start_atimer (enum atimer_type type, EMACS_TIME time, atimer_callback fn,
switch (type)
{
case ATIMER_ABSOLUTE:
- t->expiration = time;
+ t->expiration = timestamp;
break;
case ATIMER_RELATIVE:
EMACS_GET_TIME (t->expiration);
- EMACS_ADD_TIME (t->expiration, t->expiration, time);
+ EMACS_ADD_TIME (t->expiration, t->expiration, timestamp);
break;
case ATIMER_CONTINUOUS:
EMACS_GET_TIME (t->expiration);
- EMACS_ADD_TIME (t->expiration, t->expiration, time);
- t->interval = time;
+ EMACS_ADD_TIME (t->expiration, t->expiration, timestamp);
+ t->interval = timestamp;
break;
}
@@ -187,24 +187,24 @@ cancel_atimer (struct atimer *timer)
}
/* Append two lists of atimers LIST1 and LIST2 and return the
result list. */
static struct atimer *
-append_atimer_lists (struct atimer *list1, struct atimer *list2)
+append_atimer_lists (struct atimer *list_1, struct atimer *list_2)
{
- if (list1 == NULL)
- return list2;
- else if (list2 == NULL)
- return list1;
+ if (list_1 == NULL)
+ return list_2;
+ else if (list_2 == NULL)
+ return list_1;
else
{
struct atimer *p;
- for (p = list1; p->next; p = p->next)
+ for (p = list_1; p->next; p = p->next)
;
- p->next = list2;
- return list1;
+ p->next = list_2;
+ return list_1;
}
}
@@ -287,28 +287,28 @@ set_alarm (void)
{
if (atimers)
{
- EMACS_TIME now, time;
+ EMACS_TIME now, timestamp;
#ifdef HAVE_SETITIMER
struct itimerval it;
#endif
/* Determine s/us till the next timer is ripe. */
EMACS_GET_TIME (now);
- EMACS_SUB_TIME (time, atimers->expiration, now);
+ EMACS_SUB_TIME (timestamp, atimers->expiration, now);
#ifdef HAVE_SETITIMER
/* Don't set the interval to 0; this disables the timer. */
if (EMACS_TIME_LE (atimers->expiration, now))
{
- EMACS_SET_SECS (time, 0);
- EMACS_SET_USECS (time, 1000);
+ EMACS_SET_SECS (timestamp, 0);
+ EMACS_SET_USECS (timestamp, 1000);
}
memset (&it, 0, sizeof it);
- it.it_value = time;
+ it.it_value = timestamp;
setitimer (ITIMER_REAL, &it, 0);
#else /* not HAVE_SETITIMER */
- alarm (max (EMACS_SECS (time), 1));
+ alarm (max (EMACS_SECS (timestamp), 1));
#endif /* not HAVE_SETITIMER */
}
}
@@ -442,4 +442,3 @@ init_atimer (void)
/* pending_signals is initialized in init_keyboard.*/
signal (SIGALRM, alarm_signal_handler);
}
-
@@ -187,24 +187,24 @@ cancel_atimer (struct atimer *timer)
}
-/* Append two lists of atimers LIST1 and LIST2 and return the
+/* Append two lists of atimers LIST_1 and LIST_2 and return the
result list. */
static struct atimer *